@@ -35,6 +35,7 @@
 #' @template param_learner_properties
 #' @template param_data_formats
 #' @template param_packages
+#' @template param_label
 #' @template param_man
 #'
 #'
@@ -90,6 +91,9 @@ Learner = R6Class("Learner",
     #' @template field_id
     id = NULL,
 
+    #' @template field_label
+    label = NA_character_,
+
     #' @field state (`NULL` | named `list()`)\cr
     #' Current (internal) state of the learner.
     #' Contains all information gathered during `train()` and `predict()`.
@@ -150,9 +154,10 @@ Learner = R6Class("Learner",
     #'
     #' Note that this object is typically constructed via a derived classes, e.g. [LearnerClassif] or [LearnerRegr].
     initialize = function(id, task_type, param_set = ps(), predict_types = character(), feature_types = character(),
-      properties = character(), data_formats = "data.table", packages = character(), man = NA_character_) {
+      properties = character(), data_formats = "data.table", packages = character(), label = NA_character_, man = NA_character_) {
 
       self$id = assert_string(id, min.chars = 1L)
+      self$label = assert_string(label, na.ok = TRUE)
       self$task_type = assert_choice(task_type, mlr_reflections$task_types$type)
       private$.param_set = assert_param_set(param_set)
       self$feature_types = assert_subset(feature_types, mlr_reflections$task_feature_types)
@@ -176,7 +181,7 @@ Learner = R6Class("Learner",
     #' Printer.
     #' @param ... (ignored).
     print = function(...) {
-      catn(format(self))
+      catn(format(self), if (is.na(self$label)) "" else paste0(": ", self$label))
       catn(str_indent("* Model:", if (is.null(self$model)) "-" else class(self$model)[1L]))
       catn(str_indent("* Parameters:", as_short_string(self$param_set$values, 1000L)))
       catn(str_indent("* Packages:", self$packages))
@@ -475,13 +480,15 @@ Learner = R6Class("Learner",
         return(private$.fallback)
       }
 
-      assert_learner(rhs, task_type = self$task_type)
-      if (!identical(self$predict_type, rhs$predict_type)) {
-        warningf("The fallback learner '%s' and the base learner '%s' have different predict types",
-          rhs$predict_type, self$predict_type)
-      }
-      if (is.null(private$.encapsulate)) {
-        private$.encapsulate = c(train = "evaluate", predict = "evaluate")
+      if (!is.null(rhs)) {
+        assert_learner(rhs, task_type = self$task_type)
+        if (!identical(self$predict_type, rhs$predict_type)) {
+          warningf("The fallback learner '%s' and the base learner '%s' have different predict types",
+            rhs$predict_type, self$predict_type)
+        }
+        if (is.null(private$.encapsulate)) {
+          private$.encapsulate = c(train = "evaluate", predict = "evaluate")
+        }
       }
       private$.fallback = rhs
     },
