@@ -46,7 +46,8 @@ ResamplingCV = R6Class("ResamplingCV", inherit = Resampling,
       )
       ps$values = list(folds = 10L)
 
-      super$initialize(id = "cv", param_set = ps, man = "mlr3::mlr_resamplings_cv")
+      super$initialize(id = "cv", param_set = ps,
+        label = "Cross-Validation", man = "mlr3::mlr_resamplings_cv")
     }
   ),
 
