@@ -50,7 +50,8 @@ ResamplingSubsampling = R6Class("ResamplingSubsampling", inherit = Resampling,
       )
       ps$values = list(repeats = 30L, ratio = 2 / 3)
 
-      super$initialize(id = "subsampling", param_set = ps, man = "mlr3::mlr_resamplings_subsampling")
+      super$initialize(id = "subsampling", param_set = ps,
+        label = "Subsampling", man = "mlr3::mlr_resamplings_subsampling")
     }
   ),
 
