@@ -45,12 +45,13 @@ TaskClassif = R6Class("TaskClassif",
     #'   Only for binary classification: Name of the positive class.
     #'   The levels of the target columns are reordered accordingly, so that the first element of `$class_names` is the
     #'   positive class, and the second element is the negative class.
+    #' @template param_label
     #' @template param_extra_args
-    initialize = function(id, backend, target, positive = NULL, extra_args = list()) {
+    initialize = function(id, backend, target, positive = NULL, label = NA_character_, extra_args = list()) {
       assert_string(target)
       super$initialize(
         id = id, task_type = "classif", backend = backend,
-        target = target, extra_args = extra_args)
+        target = target, label = label, extra_args = extra_args)
 
       private$.update_class_property()
 
