@@ -28,7 +28,8 @@ TaskGeneratorCircle = R6Class("TaskGeneratorCircle",
         d = p_int(2L, default = 2L)
       )
 
-      super$initialize(id = "circle", "classif", "mlbench", ps, man = "mlr3::mlr_task_generators_circle")
+      super$initialize(id = "circle", "classif", "mlbench", ps,
+        label = "Circle Classification", man = "mlr3::mlr_task_generators_circle")
     },
 
     #' @description
